==> groupfolders-v20.1.2.tar.gz: groupfolders/l10n/cs.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Není možné odebrat si sám sobě oprávnění pro čtení.",
    "Team folders" : "Týmové složky",
    "Team Folders" : "Týmové složky",
    "Unset" : "Zrušit nastavení",
    "Denied (Inherited permission)" : "Odepřeno (převzaté oprávnění)",
    "Allowed (Inherited permission)" : "Umožněno (převzaté oprávnění)",
    "Denied" : "Odepřeno",
    "Allowed" : "Umožněno",
    "Access denied" : "Přístup odepřen",
    "Access allowed" : "Přístup umožněn",
    "Inherit permission" : "Přebírat oprávnění",
    "Deny" : "Odepřít",
    "Allow" : "Umožnit",
    "Group" : "Skupina",
    "Team" : "Tým",
    "Team folder" : "Týmová složka",
    "Read" : "Číst",
    "Write" : "Zapisovat",
    "Create" : "Vytvářet",
    "Delete" : "Mazat",
    "Share" : "Sdílet",
    "You" : "Vy",
    "Remove access rule" : "Odebrat pravidlo přístupu",
    "Add advanced permission rule" : "Přidat pravidlo podrobných oprávnění",
    "Select a user or group" : "Vybrat uživatele nebo skupinu",
    "Open Team folder" : "Otevřít týmovou složku",
    "Permission denied. User does not have sufficient permissions." : "Přístup odepřen. Uživatel nemá dostatečná oprávnění.",
    "Unexpected status from server" : "Neočekávaný stav ze serveru",
    "List of Team folders." : "Seznam týmových složek.",
    "No Team folders yet" : "Zatím žádné týmové složky",
    "Team folders will show up here" : "Týmové složky se zobrazí zde",
    "Add group" : "Přidat skupinu",
    "Default" : "Výchozí",
    "Unlimited" : "Neomezeně",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Opravdu chcete smazat „{folderName}“ a s ní všechny v ní obsažené soubory? Tuto operaci nelze vrátit zpět!",
    "Delete \"{folderName}\"?" : "Smazat „{folderName}“?",
    "Team folder admin delegation" : "Delegace správy týmové složky",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud umožňuje delegovat správu Týmových složek na uživatele, kteří nejsou správci celého Nextcloud.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Níže zadejte skupiny, kterým bude umožněno spravovat Týmové složky a používat jejich API/REST.",
    "They will have access to all Team folders." : "Budou mít přístup ke všem týmovým složkám.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Níže zadejte skupiny, pouze kterým bude umožněno spravovat Týmové složky a používat jejich API/REST.",
    "They will only have access to Team folders for which they have advanced permissions." : "Budou mít přístup pouze k týmovým složkám, pro které mají pokročilá oprávnění.",
    "Group or team" : "Skupina nebo tým",
    "Sort by number of groups or teams that have access to this folder" : "Seřadit podle počtu skupin nebo týmů, které mají k této složce přístup",
    "Sort by number of groups that have access to this folder" : "Seřadit podle počtu skupin, které mají k této složce přístup",
    "Folder name" : "Název složky",
    "Quota" : "Kvóta",
    "Advanced Permissions" : "Podrobná oprávnění",
    "Pagination of team folders" : "Stránkování týmových složek",
    "Previous" : "Předchozí",
    "Next" : "Next",
    "User" : "Uživatel",
    "Unknown" : "Neznámé",
    "Users/groups that can manage" : "Uživatelé/skupiny které mohou spravovat",
    "None" : "Žádná",
    "No other groups or teams available" : "Nejsou k dispozici žádné další skupiny nebo týmy",
    "No other groups available" : "Nejsou k dispozici žádné další skupiny",
    "{displayName} (team)" : "{displayName} (tým)",
    "Add group or team" : "Přidat skupinu nebo tým",
    "{size} used" : "{size} použito",
    "Other …" : "Ostatní...",
    "Admin configured folders shared with everyone in a team" : "Správcem nastavené složky sdílené s každým v týmu",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Správcem nastavované složky sdílené s kýmkoli v týmu.\n\nSložky je možné nastavovat z *Týmové složky* v nastavení správy.\n\nPo vytvoření složky, správce může udělit přístup do ní jednomu či vícero týmům, řídit jejich oprávnění k zápisu/sdílení a přiřazovat kvótu pro složku.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Správcem nastavené složky sdílené se všemi v týmu.\n\nSložky mohou být nastaveny v záložce „Týmové složky“ (v nastavení pro správce).\n\nPo vytvoření složky k ní může správce udělit přístup jednomu nebo více týmům, nastavovat jejich možnosti zapisování a sdílení a kvótu.\nPočínaje verzí Hub 10/Nextcloud 31 je třeba, aby správce byl součástí týmu, ke kterému chce složku přiřadit."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> groupfolders-v20.1.3.tar.gz: groupfolders/l10n/cs.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Není možné odebrat si sám sobě oprávnění pro čtení.",
    "Team folders" : "Týmové složky",
    "Team Folders" : "Týmové složky",
    "Shared folders managed by admins, accessible to designated teams with configurable permissions and quotas" : "Sdílené složky, spravované správci, přístupné pověřeným týmům s nastavitelnými oprávněními a kvótami",
    "Unset" : "Zrušit nastavení",
    "Denied (Inherited permission)" : "Odepřeno (převzaté oprávnění)",
    "Allowed (Inherited permission)" : "Umožněno (převzaté oprávnění)",
    "Denied" : "Odepřeno",
    "Allowed" : "Umožněno",
    "Access denied" : "Přístup odepřen",
    "Access allowed" : "Přístup umožněn",
    "Inherit permission" : "Přebírat oprávnění",
    "Deny" : "Odepřít",
    "Allow" : "Umožnit",
    "Group" : "Skupina",
    "Team" : "Tým",
    "Team folder" : "Týmová složka",
    "Read" : "Číst",
    "Write" : "Zapisovat",
    "Create" : "Vytvářet",
    "Delete" : "Mazat",
    "Share" : "Sdílet",
    "You" : "Vy",
    "Remove access rule" : "Odebrat pravidlo přístupu",
    "Add advanced permission rule" : "Přidat pravidlo podrobných oprávnění",
    "Select a user or group" : "Vybrat uživatele nebo skupinu",
    "Open Team folder" : "Otevřít týmovou složku",
    "Permission denied. User does not have sufficient permissions." : "Přístup odepřen. Uživatel nemá dostatečná oprávnění.",
    "Unexpected status from server" : "Neočekávaný stav ze serveru",
    "List of Team folders." : "Seznam týmových složek.",
    "No Team folders yet" : "Zatím žádné týmové složky",
    "Team folders will show up here" : "Týmové složky se zobrazí zde",
    "Add group" : "Přidat skupinu",
    "Default" : "Výchozí",
    "Unlimited" : "Neomezeně",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Opravdu chcete smazat „{folderName}“ a s ní všechny v ní obsažené soubory? Tuto operaci nelze vrátit zpět!",
    "Delete \"{folderName}\"?" : "Smazat „{folderName}“?",
    "Team folder admin delegation" : "Delegace správy týmové složky",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud umožňuje delegovat správu Týmových složek na uživatele, kteří nejsou správci celého Nextcloud.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Níže zadejte skupiny, kterým bude umožněno spravovat Týmové složky a používat jejich API/REST.",
    "They will have access to all Team folders." : "Budou mít přístup ke všem týmovým složkám.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Níže zadejte skupiny, pouze kterým bude umožněno spravovat Týmové složky a používat jejich API/REST.",
    "They will only have access to Team folders for which they have advanced permissions." : "Budou mít přístup pouze k týmovým složkám, pro které mají pokročilá oprávnění.",
    "Group or team" : "Skupina nebo tým",
    "Sort by number of groups or teams that have access to this folder" : "Seřadit podle počtu skupin nebo týmů, které mají k této složce přístup",
    "Sort by number of groups that have access to this folder" : "Seřadit podle počtu skupin, které mají k této složce přístup",
    "Folder name" : "Název složky",
    "Quota" : "Kvóta",
    "Advanced Permissions" : "Podrobná oprávnění",
    "Pagination of team folders" : "Stránkování týmových složek",
    "Previous" : "Předchozí",
    "Next" : "Next",
    "User" : "Uživatel",
    "Unknown" : "Neznámé",
    "Users/groups that can manage" : "Uživatelé/skupiny které mohou spravovat",
    "None" : "Žádná",
    "No other groups or teams available" : "Nejsou k dispozici žádné další skupiny nebo týmy",
    "No other groups available" : "Nejsou k dispozici žádné další skupiny",
    "{displayName} (team)" : "{displayName} (tým)",
    "Add group or team" : "Přidat skupinu nebo tým",
    "{size} used" : "{size} použito",
    "Other …" : "Ostatní...",
    "Admin configured folders shared with everyone in a team" : "Správcem nastavené složky sdílené s každým v týmu",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Správcem nastavované složky sdílené s kýmkoli v týmu.\n\nSložky je možné nastavovat z *Týmové složky* v nastavení správy.\n\nPo vytvoření složky, správce může udělit přístup do ní jednomu či vícero týmům, řídit jejich oprávnění k zápisu/sdílení a přiřazovat kvótu pro složku.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Správcem nastavené složky sdílené se všemi v týmu.\n\nSložky mohou být nastaveny v záložce „Týmové složky“ (v nastavení pro správce).\n\nPo vytvoření složky k ní může správce udělit přístup jednomu nebo více týmům, nastavovat jejich možnosti zapisování a sdílení a kvótu.\nPočínaje verzí Hub 10/Nextcloud 31 je třeba, aby správce byl součástí týmu, ke kterému chce složku přiřadit."
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
